c
c Arrange all the valence electrons to the necessary molecular orbitals 
c so that the potential energy of the system is minimized.
c
      subroutine filloc(ndim,nElect,eva,etb,occ)
c
      implicit none
      include "maxdim.h"
c
      integer ndim,nElect,i,j,nbottom,ntop,k
      double precision eva(max6),u,etb,tmp
      integer occ(max6)
c
c nElect --- number of valence electrons in the system.
c ndim --- dimension of the Hamiltonian matrix.
c
      u=0.64d0
c
c Initialize occupation number set
c
      do 10 i=1,ndim
         occ(i)=0
   10 continue
c
      if (nElect .gt. 2*ndim) stop "There is not enough MOs"
c
c Arrange electrons simply from lowest orbitals to highest orbitals
c
      nbottom=nElect/2
      if (nElect .eq. 1) then
        occ(1)=1
        etb=eva(1)
        return
      else
        do 20 i=1, nElect/2
          occ(i)=2
   20   continue
        if (2*(nElect/2) .ne. nElect) then
          occ(i)=1
          ntop=nbottom+2
        else
          ntop=nbottom+1
        endif
      endif
c
c Rearrange the occupation according to penalty energy to obtain a set of 
c occupancy to give minimum energy.
c At first, the orbitals are occupied from lowest to higher orbital with two
c electrons if there are enough electrons, which is called the starting point. 
c The rearrangement of the the molecular orbitals begins here.  The highest 
c doubly occupied orbital is called nbottom, and the lowest unoccupied MO is
c called ntop.  If the energy difference between ntop and nbottom is smaller
c than the penalty energy (u or 0.80 eV in this case), the electron from 
c nbottom jump to ntop.  Otherwise, the rearrangement will stop. 
c
      if (nbottom .eq. 0) goto 102
      if (ntop .gt. ndim) goto 102
c
 101  if (eva(nbottom)+u .gt. eva(ntop)) then 
c
c If the energy of the top orbital is higher by u than that of the bottom 
c orbital, the bottom becomes top and the number of the bottom orbital is 
c decreased by 1.
c
        occ(ntop)=1
        ntop=ntop+1
        occ(nbottom)=1
        nbottom=nbottom-1
c
        if (ntop .gt. ndim) goto 102
        if (nbottom .eq. 0) goto 102
c
        goto 101
c
      endif
c
c Calculate the energy of resulting structure.
c
 102  continue
      etb=0.0
      do k=1,ndim
        if (occ(k).eq.2) then
          etb=etb+u+eva(k)*2
        else
          etb=etb+eva(k)*occ(k)
        endif
      enddo
c
      return
      end
