C 888888888888888888888888888888888888888888888888888888888888888888
c The subroutine receives two arguments (coordinate and the minumum 
c number of atoms the program can work with) and returns two values
c (the total energy and the first derivative for each atom computed 
c numerically.
c
c Version 1.0.1 - BUGFIX: line 80: size of ap corrected to
c                 double precision ap(max6*(max6+1)/2)
c 888888888888888888888888888888888888888888888888888888888888888888
c
      SUBROUTINE SURF(V,X,DX,N3TM)
c     program tb
c
c This subroutine can be a subroutine of POLYRATE Program.
c The parameters developed will be hiden in each subroutine.
c The base orbitals will be ns + np for principal elements, (n-1)d + ns for
c transition elements.
c
      IMPLICIT NONE
     
      include "maxdim.h"
c
      character*75 space, hyphen
      parameter (space= "                                  ")
      parameter (hyphen="-----------------------------------------------
     *---------------------------")
c
c N3TM the maximum dimension of the coordinates delivered from POLYRATE.
c myatom is the number of atoms whose positions are fixed.
c
      integer n3tm,myatom
c
c i,j,ip,jp,ii,jj,k --- temporary integer variables.
c
      integer i,j,ip,jp,ii,jj,k
c
c symb --- an array holding the components of the system.
c
      character*2 symb(maxatm)
c
c idtype --- identification for each element in the system.
c 	H   Hydrogen  identification number: 1
c 	C   Hydrogen  identification number: 2
c 	Ni  Nickel    identification number: 3
c 	Cu  Copper    identification number: 4
c 	Pd  Palladium identification number: 5
c 	Ag  Silver    identification number: 6
c 	Pt  Platium   identification number: 7
c 	Au  Gold      identification number: 8
c norbit --- holding the number of orbitals for each element.
c natom --- number of atoms in the system.
c nelem --- number of valence electrons for each atom.
c nElect --- number of valence electrons in the system.
c ndim --- dimension of the Hamiltonian matrix.
c
      integer idtype(maxatm),norbit(maxatm),nelem(maxatm)
      integer ndim,natom,nElect
c 
c nrdim,ncdim,temp --- temporary variables.
c
      integer nrdim,ncdim,temp
c
c X --- Cartesian coordinates.
c vsip --- valence state ionization potential.
c
      double precision X(max3),vsip(8,2)
c
c hamil  --- interaction submatrix for two atoms.
c hamilt --- final Hamiltonian matrix for the system.
c
      double precision hamil(6,6),hamilt(max6,max6)
c
c ap  --- array passing Hamiltonian matrix to blas.
c work --- work space for blas
c evec --- molecular orbital coefficients
c eva  --- eigenvalues.
c occ  --- occupation number.
c
c Following line corrected in Version 1.0.1
      double precision ap(max6*(max6+1)/2),work(3*max6)
      double precision evec(max6,max6),eva(max6)
      integer info,occ(max6)
c  
c dx --- first derivative of the system.
c dhamil --- First derivative of hamil.
c dhamlt --- First derivatives of dhamil.
c forcex,forcey,forcez,tmp --- temporary variables.
c
      double precision dx(max3),dhamlt(max6,max6,3),dhamil(6,6,3)
      double precision forcex,forcey,forcez,tmp
c
c repul  --- pairwise repulsive energy.
c drepul --- first derivative of repul.
c eerep  --- total repulsive energy.
c
      double precision repul,drepul(3),eerep
c
c etb    --- valence band energy.
c V      --- potential energy.
c
      double precision etb,V
c
c q --- Mulliken net AO population
c qcharg --- gross AO populations for one atom.
c
      double precision q(max6),qcharg(maxatm)
c
c
c Tzero --- Total zero energy.
c
      double precision Tzero
c
      common /coulom/ vsip
c
c Main procedure begins here.
c
      ndim=0
      Tzero=0.0
c
      read (99,*) nElect
      nElect=-nElect
      do 20 i=1, maxatm
        read (99, *, end=21) symb(i)
        if (symb(i).eq.'H '.or.symb(i).eq.' H') then
          nElect=nElect+1
          nelem(i)=1
          norbit(i)=1
          idtype(i)=1
          ndim=ndim+1
          Tzero=Tzero-8.83
        else if (symb(i).eq.'C '.or.symb(i).eq.' C') then
          nElect=nElect+4
          nelem(i)=4
          norbit(i)=4
          idtype(i)=2
          ndim=ndim+4
          Tzero=Tzero-53.26
        else if ( symb(i) .eq. 'Ni' .or. symb(i) .eq. 'NI') then
          nElect=nElect+10
          nelem(i)=10
          norbit(i)=6
          idtype(i)=3
          ndim=ndim+6
          Tzero=Tzero-87.80
        else if ( symb(i) .eq. 'Cu' .or. symb(i) .eq. 'CU') then
          nElect=nElect+11
          nelem(i)=11
          norbit(i)=6
          idtype(i)=4
          ndim=ndim+6
          Tzero=Tzero-93.50-8.65+3.20
        else if ( symb(i) .eq. 'Pd' .or. symb(i) .eq. 'PD') then
          nElect=nElect+10
          nelem(i)=10
          norbit(i)=6
          idtype(i)=5
          ndim=ndim+6
          Tzero=Tzero-91.50+3.20
        else if ( symb(i) .eq. 'Ag' .or. symb(i) .eq. 'AG') then
          nElect=nElect+11
          nelem(i)=11
          norbit(i)=6
          idtype(i)=6
          ndim=ndim+6
          Tzero=Tzero-94.50-8.65+3.20
        else if ( symb(i) .eq. 'Pt' .or. symb(i) .eq. 'PT') then
          nElect=nElect+10
          nelem(i)=10
          norbit(i)=6
          idtype(i)=7
          ndim=ndim+6
          Tzero=Tzero-92.50+3.20
        else if ( symb(i) .eq. 'Au' .or. symb(i) .eq. 'AU') then
          nElect=nElect+11
          nelem(i)=11
          norbit(i)=6
          idtype(i)=8
          ndim=ndim+6
          Tzero=Tzero-96.50-8.65+3.20
c
c USER SECTION BEGINS
c   Place the information of a new added element here.
c
c       else if ( symb(i) .eq. 'Ae' .or. symb(i) .eq. 'AE') then
c         nElect=nElect+x
c         nelem(i)=y
c         norbit(i)=z
c         idtype(i)=9
c         ndim=ndim+z
c
c USER SECTION ENDS
c
        else
          stop "I don't have the parameters to handle the element"
        endif
 20   continue
      stop "Exceed the limit of the program, too many atoms."
 21   myatom=i-1
c
c Read the file containing substrate atoms which won't be optimized.
c This file is name as fort.98, which should exist all the time and
c can be empty.
c
      open(98)
      do 66 i=myatom+1, maxatm
        read(98,*,end=19) symb(i),(X(3*(i-1)+j),j=1,3)
 66   continue
      stop "Exceed the limit of the program, two many atoms."
 19   natom=i-1
      close(98)
c
c Print the header information
c
      write (30,*) "   Tight Binding Theory   "
      write (30,*) space
      write (30,*) "The present program parameterize for eight elements
     *(H, C, Ni, Cu, Pd, Ag, "
      write (30,*) "and Au), and a system can at most consist of three k
     *inds of elements (i.e.,"
      write (30,*) "H, C, and/or TR (Ni, Cu, Pd, Ag, Pt, or Au))."
      write (30,*) space
      write (30,*) "This is the output written to fort.30"
      write (30,*) space
      write (30,*) space
      write (30,*) "Following is the geometry file that was input in boh
     *rs"
      write (30,*) hyphen
      do i = 1, natom
         write (30,95) symb(i),(X(3*(i-1)+j),j=1,3)
      enddo
      write (30,*) hyphen
      write (30,*) space
c
c Convert the unit of the coordinate from bohr to angstrom.
c
      do 11 i = 1, 3*natom
         X(i)=X(i)*0.52917706d0
   11 continue
c
      write (30,*) "Following is the geometry file that was input in ang
     *stroms"
      write (30,*) hyphen
      do i = 1, natom
         write (30,95) symb(i),(X(3*(i-1)+j),j=1,3)
      enddo
      write (30,*) hyphen
      write (30,*) space
c
      nrdim=0
c
      do 30 i=1,natom
        ip=idtype(i)
        ncdim=0
        do 31 j=1,natom
          jp=idtype(j)
          if (j.eq.i) then
            do 32 ii=1,norbit(i)
              do 33 jj=1,norbit(j)
                dhamlt(nrdim+ii,ncdim+jj,1)=0.0
                dhamlt(nrdim+ii,ncdim+jj,2)=0.0
                dhamlt(nrdim+ii,ncdim+jj,3)=0.0
                if (ii.eq.jj) then
                  if (ii .eq. 1) then
                    hamilt(nrdim+ii,ncdim+jj)=vsip(ip,1)
                  else
                    hamilt(nrdim+ii,ncdim+jj)=vsip(ip,2)
                  endif
                else 
                  hamilt(nrdim+ii,ncdim+jj)=0.0
                endif
 33           continue
 32         continue
            goto 39
          else
            call lmndlm(i,j,X)
            call genrhd(ip,jp,hamil,dhamil)
            do 34 ii=1,norbit(i)
              do 35 jj=1,norbit(j)
                hamilt(nrdim+ii,ncdim+jj)=hamil(ii,jj)
                dhamlt(nrdim+ii,ncdim+jj,1)=dhamil(ii,jj,1)
                dhamlt(nrdim+ii,ncdim+jj,2)=dhamil(ii,jj,2)
                dhamlt(nrdim+ii,ncdim+jj,3)=dhamil(ii,jj,3)
 35           continue
 34         continue
          endif
 39       ncdim=ncdim+norbit(j)
 31     continue
        nrdim=nrdim+norbit(i)
 30   continue
c 
c Set up the uppermatrix to do eigenvalue calculations.
c
      do 40 i =1,ndim 
        do 41 j=i,ndim
          ap(i+(j-1)*j/2)=hamilt(i,j)
 41     continue 
 40   continue
c
c Call library routine: lapack.  In t1 the path is:
c /usr/local/lib -llapack -lblas
c
      call dspev( 'v','u',ndim,ap,eva,evec,6*maxatm,work,info ) 
c
c Call a subroutine to arrange all the valence electrons to the necessary
c molecular orbitals so that the potential energy of the system is minimized.
c
      call filloc(ndim,nElect,eva,etb,occ)
c
c Calculate Mulliken net AO Population for each atomic orbital
c Please refer to J. P. Lowe, Quantum Chemistry, p336 (Second edition,
c Acedemic press, 1993).  Note: Mulliken overlap population is zero since
c the overlap matrix here is assumed as unit matrix.
c
      do j = 1, ndim
        q(j)=0.0
        do i = 1, ndim
          q(j) = q(j) + occ(i)*evec(j,i)*evec(j,i)
        enddo
      enddo
c
      nrdim=0
      do i=1,natom
        qcharg(i)=0.0
        do j=1,norbit(i)
          qcharg(i)=qcharg(i)+q(nrdim+j)
c         do k=1,ndim
c           if (k.ne.(nrdim+j)) then
c             qcharg(i)=qcharg(i)+p(nrdim+j,k)/2.0
c           endif
c         enddo
        enddo
        nrdim=nrdim+norbit(i)
      enddo
c
c Calculate HOMO orbitals
c
      write (30,*) "Following is information about HOMO and LUMO"
      write (30,*) hyphen
      write (30,97) " MO No.", "Eigenvalue(eV)","Description"
      write (30,*) hyphen
      do i = 1, ndim
        if (occ(i).eq.2) then
          if (occ(i+1).eq.1) then
            write(30,98) i,eva(i),' This is highest doubly occupied orbi
     &tal.'
            write(30,98) i+1,eva(i+1),' This is lowest singly occupied.'
          else if (occ(i+1).eq.0) then
            write(30,98) i,eva(i),' This is highest doubly occupied orbi
     &tal.'
            write(30,*) "There is no singly-occupied orbital."
            write(30,98) i,eva(i),' This is HOMO.'
            if ((i+1) .gt. ndim) then
              write (30,*) 'There is no LUMO'
            else
              write(30,98) i+1,eva(i+1),' This is LUMO. '
            endif
            goto 44
          endif
        else if (occ(i).eq.1) then
          if (occ(i+1).eq.0) then
            write(30,98) i,eva(i),' This is HOMO.'
            if ((i+1) .gt. ndim) then
              write (30,*) 'There is no LUMO'
            else
              write(30,98) i+1,eva(i+1),' This is LUMO. '
            endif
            goto 44
          endif
        endif
      enddo
c
c Print Out eva, occ, q
c
 44   continue
      write (30,*) hyphen
      write (30,*) space
c
      do i=0,ndim/8
        if (i.lt.ndim/8) then
          write (30,*) "Eigenvalues (E in eV), occupation number(n), and
     * partial charge (q)"
          write (30,*) " followed by Hamiltonian matrix H (in eV)"
          write (30,*) hyphen
          write (30,99) "  E   ",(eva(i*8+j),j=1,8)
          write (30,103) "  n   ",(occ(i*8+j),j=1,8)
          write (30,99) "  q   ",(q(i*8+j),j=1,8)
          write (30,*) hyphen
          do k=1,ndim
            write (30,100) "  H",k,(hamilt(i*8+j,k),j=1,8)
          enddo
          write (30,*) hyphen
        else if (mod(ndim,8).ne.0) then
          write (30,*) "Eigenvalues (E in eV), occupation number(n), and
     * partial charge (q)"
          write (30,*) "followed by overlap matrix S and Hamiltonian mat
     *rix H(in eV)"
          write (30,*) hyphen
          write (30,99) "  E   ",(eva(j),j=8*i+1,ndim)
          write (30,103) "  n   ",(occ(j),j=8*i+1,ndim)
          write (30,99) "  q   ",(q(j),j=8*i+1,ndim)
          write (30,*) hyphen
          do k=1,ndim
            write (30,100) "  H",k,(hamilt(j,k),j=8*i+1,ndim)
          enddo
          write (30,*) hyphen
        endif
      enddo
      write (30,*) space
c
c Calculate the first derivative analytically.
c
        eerep=0.0
        nrdim=0
c
        do 51 i=1,natom
          ip=idtype(i)
          ncdim=0

          dx(3*(i-1)+1)=0.0
          dx(3*(i-1)+2)=0.0
          dx(3*(i-1)+3)=0.0

          do 52 j=1,natom
            jp=idtype(j)

            if (j.eq.i) goto 59
              
            call lmndlm(i,j,X)
            call genrrp(ip,jp,repul,drepul)
            
            eerep=eerep+repul/2.0

            dx(3*(i-1)+1)=dx(3*(i-1)+1)+drepul(1)
            dx(3*(i-1)+2)=dx(3*(i-1)+2)+drepul(2)
            dx(3*(i-1)+3)=dx(3*(i-1)+3)+drepul(3)

            forcex=0.d0
            forcey=0.d0
            forcez=0.d0

            do 53 k=1,ndim
              do 54 ii=1,norbit(i)
                do 55 jj=1,norbit(j)
                  tmp=evec(nrdim+ii,k)*evec(ncdim+jj,k)*occ(k)
                  forcex=forcex+tmp*dhamlt(nrdim+ii,ncdim+jj,1)
                  forcey=forcey+tmp*dhamlt(nrdim+ii,ncdim+jj,2)
                  forcez=forcez+tmp*dhamlt(nrdim+ii,ncdim+jj,3)
 55             continue
 54           continue
 53         continue
            dx(3*(i-1)+1)=dx(3*(i-1)+1)+2.d0*forcex
            dx(3*(i-1)+2)=dx(3*(i-1)+2)+2.d0*forcey
            dx(3*(i-1)+3)=dx(3*(i-1)+3)+2.d0*forcez
 59         ncdim=ncdim+norbit(j)
 52       continue
          nrdim=nrdim+norbit(i)
c
 51     continue
c
c Convert Cartesian coordinates from Angstrom to bohr, first derivative from
c eV/(Angstrom) to Hartree/bohr.
c
c The binding energy is given in unit of eV.
c
      V=etb+eerep-Tzero
      V=V/27.21161
      do 60 i = 1, 3*natom
        X(i)=X(i)/0.52917706d0
        DX(i)=DX(i)*0.019446738d0
   60 continue
c
c print out some information about the configuration.
c
      write (30,102) "The energy of the system is ", V, " hartrees = ",
     &V*27.21161, "eV = ", V*627.50, " kcal/mol."
      write (30,*) hyphen
      write (30,*) space
      write (30,*) "Element    Electrons  Charges     dx          dy
     *   dz(a.u./bohr)"
      write (30,*) hyphen
      do i=1,natom
        write (30,101)symb(i),qcharg(i),nelem(i)-qcharg(i),
     *         (dx(3*(i-1)+j),j=1,3)
      enddo
      write (30,*) hyphen
      write (30,*) "                                   THE END"
 95   format (T5,A,T10,3f10.5)
 97   format (T1,A,T13,A,T39,A)
 98   format (T1,I3,T9,f12.4,T30,A)
 99   format(T1,A8,8(f9.4))
 100  format(T1,A3,I3,8(f9.4))
 101  format(T3,A,T10,5(f10.5))
 102  format(T1,A,T26,f8.5,T34,A,T46,f10.3,T57,A,T61,f10.3,T71,A)
 103  format(T1,A8,8(I9))
c
      return
      END 
