c
c This is a subroutine to compute the overlap integral between s
c orbital and dxxyy orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In sds the first s means s orbital (angular quantum number is 0),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c

      subroutine sxxyy(sds,dsds,hamil,dhamil)

      implicit none
      double precision sds,dsds,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,hsqrt3
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you want to compute the integral between dxxyy and s, just replace 
c sds and dsds with dss and dsss.
c

      hsqrt3=sqrt(3.0)/2.0

      hamil=hsqrt3*llmimm*sds

      dhamil(1)=hsqrt3*(llmimm*dsds*l+2.0*(l*dlx-m*dmx)*sds)
      dhamil(2)=hsqrt3*(llmimm*dsds*m+2.0*(l*dly-m*dmy)*sds)
      dhamil(3)=hsqrt3*(llmimm*dsds*n+2.0*(l*dlz-m*dmz)*sds)

      return
      end

