c
c This is a subroutine to compute the overlap integral between s
c orbital and dxy (dyz or dzx) orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c sds is the two-center integral between the s orbital and d orbital when the
c line connecting the two atoms is the z axis, and dpps is the first derivative
c of sds with respect to the distance between the two atoms.
c
c In sds the first s means s orbital (angular quantum number is 0),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c For the input the character c is xy, yz, and zx reprenting the overlap
c integral between s orbital and dxy, or dyz, or dzx respectively.
c

      subroutine sxy(c,sds,dsds,hamil,dhamil)

      implicit none
      character*2 c
      double precision sds,dsds,el,em,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,sqrt3
      double precision delx,dely,delz,demx,demy,demz
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

      sqrt3=sqrt(3.0)

      if(c(1:1).eq.'x') then
        if(c(2:2).eq.'y') then
          el=l
          delx=dlx
          dely=dly
          delz=dlz
          em=m
          demx=dmx
          demy=dmy
          demz=dmz
        endif
      else if(c(1:1).eq.'y')then
        if(c(2:2).eq.'z') then
          el=m
          delx=dmx
          dely=dmy
          delz=dmz
          em=n
          demx=dnx
          demy=dny
          demz=dnz
        endif
      else if(c(1:1).eq.'z') then
        if(c(2:2).eq.'x') then
          el=l
          delx=dlx
          dely=dly
          delz=dlz
          em=n
          demx=dnx
          demy=dny
          demz=dnz
        endif
      endif

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c

      hamil=sqrt3*el*em*sds

      dhamil(1)=sqrt3*((delx*em+el*demx)*sds+el*em*dsds*l)
      dhamil(2)=sqrt3*((dely*em+el*demy)*sds+el*em*dsds*m)
      dhamil(3)=sqrt3*((delz*em+el*demz)*sds+el*em*dsds*n)

      return
      end
