c
c This is a subroutine to compute the overlap integral between s orbital and
c px (py or pz) orbital when the directional cosines of the two atoms is l, m,
c and n.
c
c In sps the first s means s orbital (angular quantum number is 0), the 
c second p also means p orbital (angular quantum number is 1), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c For the input the character c is x, y, and z reprenting the overlap integral
c between s and px, py, and pz respectively.
c

      subroutine sxyz(c,sps,dsps,hamil,dhamil)

      implicit none
      character*1 c
      double precision sps,dsps,el,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,dx,dy,dz
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

      if(c.eq.'x') then
        el=l
        dx=dlx
        dy=dly
        dz=dlz
      else if(c.eq.'y')then
        el=m
        dx=dmx
        dy=dmy
        dz=dmz
      else if(c.eq.'z')then
        el=n
        dx=dnx
        dy=dny
        dz=dnz
      else
        stop "Wrong in subroutine sxyz."
      endif

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c 
c If you want to get the overlap integral between px (py or pz) and s
c chang sps and dsps into pss and dpss, and reverse the sign of  the 
c following terms.
c

      hamil=el*sps

      dhamil(1)=el*dsps*l+dx*sps
      dhamil(2)=el*dsps*m+dy*sps
      dhamil(3)=el*dsps*n+dz*sps

      return
      end
