c
c This is a subroutine to compute the overlap integral between s
c orbital and dxxyy orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In sds the first s means s orbital (angular quantum number is 0),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c

      subroutine szz (sds,dsds,hamil,dhamil)

      implicit none
      double precision sds,dsds,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you want to compute the integral between dxxyy and s, just replace
c sds and dsds with dss and dsss.
c

      hamil=(1.5*nn-0.5)*sds

      dhamil(1)=(1.5*nn-0.5)*dsds*l+3.0*n*dnx*sds
      dhamil(2)=(1.5*nn-0.5)*dsds*m+3.0*n*dny*sds
      dhamil(3)=(1.5*nn-0.5)*dsds*n+3.0*n*dnz*sds

      return
      end

