c
c This is a subroutine to compute the overlap integral between px (py, pz)
c orbital and px (py or pz) orbital when the directional cosines of the two 
c atoms is l, m, and n. 
c
c In pps the first p means p orbital (angular quantum number is 1), 
c the second p means p orbital (angular quantum number is 1), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In ppp the first p means p orbital (angular quantum number is 1), 
c the second p means p orbital (angular quantum number is 1), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1 
c or -1, otherwise the ppp is 0).
c
c For the input the character c is x, y, and z reprenting the overlap integral
c between px and px, py and py, or pz and pz respectively.
c

      subroutine xx(c,pps,dpps,ppp,dppp,hamil,dhamil)

      implicit none
      character*1 c
      double precision pps,dpps,ppp,dppp,el,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,temp,dtemp
      double precision delx,dely,delz
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

      if(c(1:1).eq.'x') then
        el=l
        delx=dlx
        dely=dly
        delz=dlz
      else if(c(1:1).eq.'y')then
        el=m
        delx=dmx
        dely=dmy
        delz=dmz
      else if(c(1:1).eq.'z') then
        el=n
        delx=dnx
        dely=dny
        delz=dnz
      endif

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c

      temp=pps-ppp
      dtemp=dpps-dppp

      hamil=el*el*temp+ppp

      dhamil(1)=2.0*el*delx*temp+(el*el*dtemp+dppp)*l
      dhamil(2)=2.0*el*dely*temp+(el*el*dtemp+dppp)*m
      dhamil(3)=2.0*el*delz*temp+(el*el*dtemp+dppp)*n

      return
      end
