c
c This is a subroutine to compute the overlap integral between px (py, pz)
c orbital and dxy(dyz or dzx) orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In pds the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In pdp the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c For the input the character c is xy, xz, yz, yx, zy, and zx reprenting the 
c overlap integral between px and dxy, px and dzx, py and dxy, py and dyz, 
c pz and dyz, and pz and dzx respectively.
c

      subroutine xxy(c,pds,dpds,pdp,dpdp,hamil,dhamil)

      implicit none
      character*2 c
      double precision pds,dpds,pdp,dpdp,el,em,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,sqrt3,tmp,dtmp
      double precision delx,dely,delz,demx,demy,demz
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

      sqrt3=sqrt(3.0)

      if(c(1:1).eq.'x') then
        if(c(2:2).eq.'y') then
          el=l
          delx=dlx
          dely=dly
          delz=dlz
          em=m
          demx=dmx
          demy=dmy
          demz=dmz
        else if(c(2:2).eq.'z') then
          el=l
          delx=dlx
          dely=dly
          delz=dlz
          em=n
          demx=dnx
          demy=dny
          demz=dnz
        endif
      else if(c(1:1).eq.'y')then
        if(c(2:2).eq.'z') then
          el=m
          delx=dmx
          dely=dmy
          delz=dmz
          em=n
          demx=dnx
          demy=dny
          demz=dnz
        endif
        if(c(2:2).eq.'x') then
          el=m
          delx=dmx
          dely=dmy
          delz=dmz
          em=l
          demx=dlx
          demy=dly
          demz=dlz
        endif
      else if(c(1:1).eq.'z')then
        if(c(2:2).eq.'y') then
          el=n
          delx=dnx
          dely=dny
          delz=dnz
          em=m
          demx=dmx
          demy=dmy
          demz=dmz
        endif
        if(c(2:2).eq.'x') then
          el=n
          delx=dnx
          dely=dny
          delz=dnz
          em=l
          demx=dlx
          demy=dly
          demz=dlz
        endif
      endif

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you have to calculate the overlap integrel between dxy and px replace
c pds and pdp with dps and dpp and then reverse the sign the results.
c

      tmp=sqrt3*pds-2.0*pdp
      dtmp=sqrt3*dpds-2.0*dpdp

      hamil=em*(el*el*tmp+pdp)

      dhamil(1)=demx*(el*el*tmp+pdp)+em*(2.0*el*delx*tmp
     +    +(el*el*dtmp+dpdp)*l)    

      dhamil(2)=demy*(el*el*tmp+pdp)+em*(2.0*el*dely*tmp
     +    +(el*el*dtmp+dpdp)*m)    

      dhamil(3)=demz*(el*el*tmp+pdp)+em*(2.0*el*delz*tmp
     +    +(el*el*dtmp+dpdp)*n)    

      return
      end
