c
c This is a subroutine to compute the overlap integral between dx2-y2
c orbital and dx2-y2 orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In dds the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In ddp the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c In ddd the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 2
c or -2, otherwise the ppp is 0).
c

      subroutine xxyy_2 (dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil)

      implicit none
      double precision dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz
      double precision tmpa,dtmpa,tmpb,dtmpb

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz


      tmpa=(3.0*dds-4.0*ddp+ddd)/4.0
      dtmpa=(3.0*ddds-4.0*dddp+dddd)/4.0
      tmpb=ddp-ddd
      dtmpb=dddp-dddd

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you have to calculate the overlap integrel between dx2-y2 and px replace
c pds and pdp with dps and dpp and then reverse the sign the results.
c

      hamil=llmimm*llmimm*tmpa+lladmm*tmpb+ddd

      dhamil(1)=4.0*llmimm*(l*dlx-m*dmx)*tmpa+llmimm*llmimm*dtmpa*l
     +         +2.0*(l*dlx+m*dmx)*tmpb+(lladmm*dtmpb+dddd)*l

      dhamil(2)=4.0*llmimm*(l*dly-m*dmy)*tmpa+llmimm*llmimm*dtmpa*m
     +         +2.0*(l*dly+m*dmy)*tmpb+(lladmm*dtmpb+dddd)*m

      dhamil(3)=4.0*llmimm*(l*dlz-m*dmz)*tmpa+llmimm*llmimm*dtmpa*n
     +         +2.0*(l*dlz+m*dmz)*tmpb+(lladmm*dtmpb+dddd)*n

      return
      end
