c
c This is a subroutine to compute the overlap integral between dxy
c orbital and dxy orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In dds the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In ddp the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c In ddd the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 2
c or -2, otherwise the ppp is 0).
c

      subroutine xxyyzz (dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil)

      implicit none
      double precision dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,qsqrt3
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz
      double precision tmpa,dtmpa,tmpb,dtmpb

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you have to calculate the overlap integrel between dx2-y2 and px replace
c pds and pdp with dps and dpp and then reverse the sign the results.
c

      qsqrt3=sqrt(3.0)/4.0

      tmpa=qsqrt3*(3.0*dds-4.0*ddp+ddd)
      dtmpa=qsqrt3*(3.0*ddds-4.0*dddp+dddd)
      tmpb=-qsqrt3*(dds-ddd)
      dtmpb=-qsqrt3*(ddds-dddd)

      hamil=llmimm*(nn*tmpa+tmpb)

      dhamil(1)=2.0*(l*dlx-m*dmx)*(nn*tmpa+tmpb)
     +    +llmimm*(2.0*n*dnx*tmpa+(nn*dtmpa+dtmpb)*l)

      dhamil(2)=2.0*(l*dly-m*dmy)*(nn*tmpa+tmpb)
     +    +llmimm*(2.0*n*dny*tmpa+(nn*dtmpa+dtmpb)*m)

      dhamil(3)=2.0*(l*dlz-m*dmz)*(nn*tmpa+tmpb)
     +    +llmimm*(2.0*n*dnz*tmpa+(nn*dtmpa+dtmpb)*n)

      return
      end
