c
c This is a subroutine to compute the overlap integral between px (py, pz)
c orbital and py (pz or px) orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In pps the first p means p orbital (angular quantum number is 1),
c the second p means p orbital (angular quantum number is 1), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In ppp the first p means p orbital (angular quantum number is 1),
c the second p means p orbital (angular quantum number is 1), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c For the input the character c is xy, xz, and yz reprenting the overlap 
c integral between px and py or py and px, px and pz or pz and px, and py and
c pz or pz and py respectively.
c

      subroutine xy(c,pps,dpps,ppp,dppp,hamil,dhamil)

      implicit none
      character*2 c
      double precision pps,dpps,ppp,dppp,el,em,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,temp,dtemp
      double precision delx,dely,delz,demx,demy,demz
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

      if(c(1:1).eq.'x') then
        if(c(2:2).eq.'y') then
          el=l
          delx=dlx
          dely=dly
          delz=dlz
          em=m
          demx=dmx
          demy=dmy
          demz=dmz
        else if(c(2:2).eq.'z') then
          el=l
          delx=dlx
          dely=dly
          delz=dlz
          em=n
          demx=dnx
          demy=dny
          demz=dnz
        endif
      else if(c(1:1).eq.'y')then
        if(c(2:2).eq.'z') then
          el=m
          delx=dmx
          dely=dmy
          delz=dmz
          em=n
          demx=dnx
          demy=dny
          demz=dnz
        endif
      endif

      temp=pps-ppp
      dtemp=dpps-dppp

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c

      hamil=el*em*temp

      dhamil(1)=(delx*em+el*demx)*temp+el*em*dtemp*l
      dhamil(2)=(dely*em+el*demy)*temp+el*em*dtemp*m
      dhamil(3)=(delz*em+el*demz)*temp+el*em*dtemp*n

      return
      end
