c
c This is a subroutine to compute the overlap integral between dxy
c orbital and dx2_y2 orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In dds the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In ddp the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c In ddd the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 2
c or -2, otherwise the ppp is 0).
c

      subroutine xyxxyy (dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil)

      implicit none
      double precision dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz
      double precision tmpa,dtmpa

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c

      tmpa=1.5*dds-2.0*ddp+0.5*ddd
      dtmpa=1.5*ddds-2.0*dddp+0.5*dddd

      hamil=l*m*llmimm*tmpa

      dhamil(1)=(dlx*m*llmimm+l*dmx*llmimm+l*m*2.0*(l*dlx-m*dmx))*tmpa
     +    +l*m*llmimm*dtmpa*l

      dhamil(2)=(dly*m*llmimm+l*dmy*llmimm+l*m*2.0*(l*dly-m*dmy))*tmpa
     +    +l*m*llmimm*dtmpa*m

      dhamil(3)=(dlz*m*llmimm+l*dmz*llmimm+l*m*2.0*(l*dlz-m*dmz))*tmpa
     +    +l*m*llmimm*dtmpa*n

      return
      end
