c
c This is a subroutine to compute the overlap integral between dxy
c orbital and dxy orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In dds the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In ddp the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c In ddd the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 2
c or -2, otherwise the ppp is 0).
c
c Character c xy representing dxy and dxy, yz dyz and dyz, zx dzx and dzx.
c

      subroutine xyxy(c,dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil)

      implicit none
      character*2 c
      double precision dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,el,em,en
      double precision delx,dely,delz,demx,demy,demz,denx,deny,denz
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz
      double precision tmpa,tmpb,dtmpa,dtmpb

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

      if (c(1:2).eq.'xy') then
          el=l
          delx=dlx
          dely=dly
          delz=dlz
          em=m
          demx=dmx
          demy=dmy
          demz=dmz
          en=n
          denx=dnx
          deny=dny
          denz=dnz
      else if (c(1:2).eq.'yz') then
          el=m
          delx=dmx
          dely=dmy
          delz=dmz
          em=n
          demx=dnx
          demy=dny
          demz=dnz
          en=l
          denx=dlx
          deny=dly
          denz=dlz
      else if (c(1:2).eq.'zx') then
          el=n
          delx=dnx
          dely=dny
          delz=dnz
          em=l
          demx=dlx
          demy=dly
          demz=dlz
          en=m
          denx=dmx
          deny=dmy
          denz=dmz
      else
        stop "Wrong for input to subroutine xyxy."
      endif

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you have to calculate the overlap integrel between dx2-y2 and px replace
c pds and pdp with dps and dpp and then reverse the sign the results.
c

      tmpa=3.0*dds-4.0*ddp+ddd
      dtmpa=3.0*ddds-4.0*dddp+dddd
      tmpb=ddp-ddd
      dtmpb=dddp-dddd

      hamil=el*el*em*em*tmpa+(el*el+em*em)*tmpb+ddd

      dhamil(1)=2.0*(el*delx*em*em+el*el*em*demx)*tmpa
     +         +(el*el*em*em*dtmpa+dddd+(el*el+em*em)*dtmpb)*l
     +         +2.0*(el*delx+em*demx)*tmpb

      dhamil(2)=2.0*(el*dely*em*em+el*el*em*demy)*tmpa
     +         +(el*el*em*em*dtmpa+dddd+(el*el+em*em)*dtmpb)*m
     +         +2.0*(el*dely+em*demy)*tmpb

      dhamil(3)=2.0*(el*delz*em*em+el*el*em*demz)*tmpa
     +         +(el*el*em*em*dtmpa+dddd+(el*el+em*em)*dtmpb)*n
     +         +2.0*(el*delz+em*demz)*tmpb

      return
      end
