c
c This is a subroutine to compute the overlap integral between dxy
c orbital and dyz orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In dds the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In ddp the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c In ddd the first d means d orbital (angular quantum number is 2),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 2
c or -2, otherwise the ppp is 0).
c
c Character c xz representing dxy and dyz or dyz and dxy, yz dxy and dzx or 
c dzx and dxy, xy dyz and dzx or dzx and dyz.
c

      subroutine xyyz (c,dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil)

      implicit none
      character*2 c
      double precision dds,ddds,ddp,dddp,ddd,dddd,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,el,em,en
      double precision delx,dely,delz,demx,demy,demz,denx,deny,denz
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz
      double precision tmpa,tmpb,dtmpa,dtmpb

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

      if (c(1:2).eq.'xz'.or.c(1:2).eq.'zx') then
          el=l
          delx=dlx
          dely=dly
          delz=dlz
          em=m
          demx=dmx
          demy=dmy
          demz=dmz
          en=n
          denx=dnx
          deny=dny
          denz=dnz
      else if (c(1:2).eq.'zy'.or.c(1:2).eq.'yz') then
          el=n
          delx=dnx
          dely=dny
          delz=dnz
          em=l
          demx=dlx
          demy=dly
          demz=dlz
          en=m
          denx=dmx
          deny=dmy
          denz=dmz
      else if (c(1:2).eq.'yx'.or.c(1:2).eq.'xy') then
          el=m
          delx=dmx
          dely=dmy
          delz=dmz
          em=n
          demx=dnx
          demy=dny
          demz=dnz
          en=l
          denx=dlx
          deny=dly
          denz=dlz
      else
        stop "Wrong for input to subroutine xyyz."
      endif

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c

      tmpa=3.0*dds-4.0*ddp+ddd
      dtmpa=3.0*ddds-4.0*dddp+dddd
      tmpb=ddp-ddd
      dtmpb=dddp-dddd

      hamil=el*en*(em*em*tmpa+tmpb)

      dhamil(1)=(delx*en+el*denx)*(em*em*tmpa+tmpb)
     +    +el*en*(2.0*em*demx*tmpa+(em*em*dtmpa+dtmpb)*l)

      dhamil(2)=(dely*en+el*deny)*(em*em*tmpa+tmpb)
     +    +el*en*(2.0*em*demy*tmpa+(em*em*dtmpa+dtmpb)*m)

      dhamil(3)=(delz*en+el*denz)*(em*em*tmpa+tmpb)
     +    +el*en*(2.0*em*demz*tmpa+(em*em*dtmpa+dtmpb)*n)

      return
      end
