c
c This is a subroutine to compute the overlap integral between px (py, pz)
c orbital and px (py or pz) orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In pds the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In pdp the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c This is for px and dyz, py and dzx, or pz and dxy.
c

      subroutine xyz(pds,dpds,pdp,dpdp,hamil,dhamil)

      implicit none
      double precision pds,dpds,pdp,dpdp,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,sqrt3,temp,dtemp
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you have to calculate the overlap integrel between dyz and px replace
c pds and pdp with dps and dpp and then reverse the sign the results.
c

      sqrt3=sqrt(3.0)

      temp=sqrt3*pds-2.0*pdp
      dtemp=sqrt3*dpds-2.0*dpdp

      hamil=l*m*n*temp

      dhamil(1)=(dlx*m*n+l*dmx*n+l*m*dnx)*temp+l*m*n*dtemp*l
      dhamil(2)=(dly*m*n+l*dmy*n+l*m*dny)*temp+l*m*n*dtemp*m
      dhamil(3)=(dlz*m*n+l*dmz*n+l*m*dnz)*temp+l*m*n*dtemp*n

      return
      end
