c
c This is a subroutine to compute the overlap integral between px (or py)
c orbital and dz2 orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In pds the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In pdp the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c
c The input character c with x, y representing px, py with dz2.
c

      subroutine xzz(c,pds,dpds,pdp,dpdp,hamil,dhamil)

      implicit none
      character*1 c
      double precision pds,dpds,pdp,dpdp,el,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,delx,dely,delz,sqrt3
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz,tmp,dtmp

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

      if (c.eq.'x') then
        el=l
        delx=dlx
        dely=dly
        delz=dlz
      else if (c.eq.'y') then
        el=m
        delx=dmx
        dely=dmy
        delz=dmz
      else
        stop "Wrong for input to subroutine xzz."
      endif

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you have to calculate the overlap integrel between dz2 and px replace
c pds and pdp with dps and dpp and then reverse the sign the results.
c

      sqrt3=sqrt(3.0)

      tmp=1.5*pds-sqrt3*pdp
      dtmp=1.5*dpds-sqrt3*dpdp

      hamil=el*(nn*tmp-0.5*pds)

      dhamil(1)=delx*(nn*tmp-0.5*pds)+el*(2.0*n*dnx*tmp
     +    +(nn*dtmp-0.5*dpds)*l)

      dhamil(2)=dely*(nn*tmp-0.5*pds)+el*(2.0*n*dny*tmp
     +    +(nn*dtmp-0.5*dpds)*m)

      dhamil(3)=delz*(nn*tmp-0.5*pds)+el*(2.0*n*dnz*tmp
     +    +(nn*dtmp-0.5*dpds)*n)

      return
      end
