c
c This is a subroutine to compute the overlap integral between py
c orbital and dx2-y2 orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In pds the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In pdp the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c

      subroutine yxxyy(pds,dpds,pdp,dpdp,hamil,dhamil)

      implicit none
      double precision pds,dpds,pdp,dpdp,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,hsqrt3,tmp,dtmp
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you have to calculate the overlap integrel between dx2-y2 and py replace
c pds and pdp with dps and dpp and then reverse the sign the results.
c

      hsqrt3=sqrt(3.0)/2.0

      tmp=hsqrt3*pds-pdp
      dtmp=hsqrt3*dpds-dpdp

      hamil=m*(llmimm*tmp-pdp)

      dhamil(1)=dmx*(llmimm*tmp-pdp)+m*(2.0*(l*dlx-m*dmx)*tmp
     +    +(llmimm*dtmp-dpdp)*l)

      dhamil(2)=dmy*(llmimm*tmp-pdp)+m*(2.0*(l*dly-m*dmy)*tmp
     +    +(llmimm*dtmp-dpdp)*m)

      dhamil(3)=dmz*(llmimm*tmp-pdp)+m*(2.0*(l*dlz-m*dmz)*tmp
     +    +(llmimm*dtmp-dpdp)*n)

      return
      end

