c
c This is a subroutine to compute the overlap integral between pz
c orbital and dz2 orbital when the directional cosines of the two
c atoms is l, m, and n.
c
c In pds the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third s
c means sigma bonding (the magnetic quantum number for the two orbitals is 0,
c otherwise the sps is 0).
c
c In pdp the first p means p orbital (angular quantum number is 1),
c the second d means d orbital (angular quantum number is 2), and the third p
c means sigma bonding (the magnetic quantum number for the two orbitals is 1
c or -1, otherwise the ppp is 0).
c

      subroutine zzz(pds,dpds,pdp,dpdp,hamil,dhamil)

      implicit none
      double precision pds,dpds,pdp,dpdp,hamil,dhamil(3)
      double precision l,m,n,lladmm,llmimm,nn,sqrt3,tmp,dtmp
      double precision dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following common blocks give the directional cosines and some
c combinations of the directional cosines, and the first derivatives of the
c directional cosines, which are generated by a subroutine lmndlm.
c

      common /lmn/ l,m,n,lladmm,llmimm,nn
      common /dlmn/ dlx,dly,dlz,dmx,dmy,dmz,dnx,dny,dnz

c
c The following codes uses Slater-Koster scheme to build Hamiltonian
c Interaction elements.  The reference:  J.C. Slater and G.F. Koster,
c Phys. Rev. 94, 1498-1524 (1954).  Especially Table 1, pp. 1503.
c
c If you have to calculate the overlap integrel between dx2-y2 and px replace
c pds and pdp with dps and dpp and then reverse the sign the results.
c

      sqrt3=sqrt(3.0)

      tmp=-0.5*pds+sqrt3*pdp
      dtmp=-0.5*dpds+sqrt3*dpdp

      hamil=n*(nn*pds+lladmm*tmp)

      dhamil(1)=dnx*(nn*pds+lladmm*tmp)+n*((nn*dpds+lladmm*dtmp)*l
     +    +2.0*(n*dnx*pds+(l*dlx+m*dmx)*tmp))

      dhamil(2)=dny*(nn*pds+lladmm*tmp)+n*((nn*dpds+lladmm*dtmp)*m
     +    +2.0*(n*dny*pds+(l*dly+m*dmy)*tmp))

      dhamil(3)=dnz*(nn*pds+lladmm*tmp)+n*((nn*dpds+lladmm*dtmp)*n
     +    +2.0*(n*dnz*pds+(l*dlz+m*dmz)*tmp))

      return
      end
